%
% Compressor map routine. The data is based on radial compressor data
% described in the NASA TM X-3552 report. The original map was scaled 
% in order to fit the design point of the Whittle compressor.
%
% [mcorr1,etac,ncorr1] = get_compressor_operating_point(i,rc)
%
% where:
% 
% Input is
%           i = index for selecting rotational speed line (i=1,8)
%               i = 7 => design rotational speed.
%          rc = compressor pressure ratio
%
% Output is 
%        etac = compressor efficiency
%      mcorr1 = compressor corrected mass flow
%      ncorr1 = compressor corrected rotational speed
% 
%
function [mcorr1,etac,ncorr1] = get_compressor_operating_point(i,rc);

global compr_map rot_speeds

if rc > compr_map(20,i,1)
    error('comp_char:run_time','Compressor surge - requested rc too high')
end
if rc < compr_map(1,i,1)
    error('comp_char:run_time','Compressor choke - requested rc too low')
end

mcorr1 = interp1(compr_map(:,i,1),compr_map(:,i,2),rc,'spline');
etac = interp1(compr_map(:,i,1),compr_map(:,i,3),rc,'spline');
ncorr1 = rot_speeds(i);
