%
% Simple function that gives single curve turbine
% mass flow characteristic, as in FIG 8.3 on page 377 
% in C.R.S. (5:th edition). Efficiency should be 
% assumed constant for all rotational speeds.
%
%    mfp3 = get_turbine_operating_point(P03_P04,gamma_g,A3,R);
%
% where:
%
% Input
%
%     P03_P04 = turbine pressure ratio 
%     gamma_g = specific heat ratio for gas
%          A3 = turbine area
%           R = gas constant
%
% Output 
%
%      mfp3 = corrected turbine mass flow. 
%
function mfp3 = get_turbine_operating_point(P03_P04,gamma_g,A3,R);

pia = 2.15; 
xfunc = sqrt(gamma_g/R)*((gamma_g+1.0)/2.0)^(-(gamma_g+1)/(2.0*(gamma_g-1.0)));

if P03_P04 >= 2.15 
    % turbine operates choked
    mfp3 = A3*xfunc;
else
    % turbine operates unchoked
    mfp3 = A3*xfunc*sqrt(1.0-((pia/P03_P04-1.0)/(pia-1.0))^2);
end 
