%
%
% Generates a plot of the single curve turbine
% characteristic represented by the get_turbine_operating_point
% function. The plot is similare to FIG 8.3 on page 377 
% in C.R.S. (5:th edition). 
%
% Efficiency is assumed constant.
%
%     function plot_turb_char(A3)
%
% Input: 
%        A3 = turbine area
%
function plot_turb_char(A3)

R = 287.0;
gamma_g = 1.333;

pi_vec = 1.0:0.1:10;
npts = length(pi_vec);

for i=1:npts,
    mcorr_vec(i) = get_turbine_operating_point(pi_vec(i),gamma_g,A3,R);
end 

plot(pi_vec,mcorr_vec,'k-')

title('Whittle turbine characteristic','FontSize',20)
ylabel('m\surd T_{03}/ P_{03}','FontSize',16)
xlabel('r_t','FontSize',20)
